'use strict';

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var chalk = require('chalk');
var resolve = require('../resolve');

/*
readmeData

# Title
## Topic Title
** Bold Title **
Text
[link label](url)
# Title 2
## Topic 2 Title
*/

// ----- to -----
// const readmeDTO = {
// 	sections: {
// 		"Title": {
// 			name: 'Title',
// 			topics: {
// 				'Topic Title': {
// 					name: 'Topic Title',
// 					text: '<bold>Bold Title</bold>\nText <underlined>link lable</underlined>',
// 					links: [{ 'link label': 'url' }],
// 				},
// 			},
// 		},
// 		'Title 2': {
// 			name: 'Title 2',
// 			topics: {
// 				'Topic Title 2': {
// 					name: 'Topic Title 2',
// 					text: '',
// 					links: [],
// 				},
// 			},
// 		},
// 	},
// };

var getNameFromReadme = function getNameFromReadme(data) {
	var spl = data.split('\n');
	return spl[0].trim();
};
var getTextFromReadme = function getTextFromReadme(data) {
	var spl = data.split('\n');
	if (spl.length < 2) {
		return '';
	}
	return spl.slice(1, spl.length).join('\n');
};
var extractLinksFromReadme = function extractLinksFromReadme(readmeData) {
	// eslint-disable-next-line
	var reg = /\[([^\]]*)\]\(([^\)]*)\)/g;
	var results = void 0;
	var text = readmeData;
	var links = [];

	// eslint-disable-next-line
	while ((results = reg.exec(readmeData)) !== null) {
		links.push(_defineProperty({}, results[1], results[2]));
		// eslint-disable-next-line
		text = text.replace('[' + results[1] + '](' + results[2] + ')', chalk.underline(results[1]));
	}

	return {
		text: text,
		links: links
	};
};

var getTopicDTOFromReadme = function getTopicDTOFromReadme(topic) {
	return _defineProperty({}, getNameFromReadme(topic), extractLinksFromReadme(getTextFromReadme(topic)));
};

var getTopicDTOsFromReadme = function getTopicDTOsFromReadme(topics) {
	var out = {};
	topics.forEach(function (topic) {
		Object.assign(out, getTopicDTOFromReadme(topic));
	});
	return out;
};

/**
 * @param {string} readmeData - the readme files data
 * @param {Object} di - dependency injection
 * @returns {Object} config - returns the contributebuddy config
 **/
function convertReadme2ReadmeDTO(readmeData) {
	var sections = readmeData.split('\n# ');
	var out = { sections: {} };
	sections.forEach(function (section) {
		if (section === '') {
			return;
		}
		var topcisSpl = section.split('\n## ');
		out.sections[getNameFromReadme(topcisSpl[0])] = Object.assign(extractLinksFromReadme(getTextFromReadme(topcisSpl[0])), {
			topics: getTopicDTOsFromReadme(topcisSpl.slice(1, topcisSpl.length))
		});
	});
	return out;
}

module.exports = resolve(convertReadme2ReadmeDTO, {});
module.exports.convertReadme2ReadmeDTO = convertReadme2ReadmeDTO;