'use strict';

var fs = require('fs');
var path = require('path');
var resolve = require('../resolve');
var getConfig = require('../getConfig');
var getConfigFilePath = require('../getConfigFilePath');
var getCwd = require('../getCwd');
var getLabel = require('../getLabel');
var convertReadme2ReadmeDTO = require('../convertReadme2ReadmeDTO');

/**
 * @param {Object} di - dependency injection
 * @returns {Object} config - returns the contributebuddy config
 **/
function getReadmeFiles(_ref) {
	var _getConfig = _ref._getConfig,
	    _getConfigFilePath = _ref._getConfigFilePath,
	    _getCwd = _ref._getCwd,
	    _convertReadme2ReadmeDTO = _ref._convertReadme2ReadmeDTO,
	    _path = _ref._path,
	    _fs = _ref._fs,
	    _console = _ref._console;

	var config = _getConfig();
	var configFilePath = _getConfigFilePath();
	var cwd = _getCwd();
	var readmeFilesData = [];

	if (!config || !config.files || !Array.isArray(config.files)) {
		_console.error(getLabel('topics.config.files.missing', { path: configFilePath.replace(cwd, '') }));
		return {};
	}

	config.files.forEach(function (fileObj) {
		// add leading empty line to make sure split will work as expected
		readmeFilesData.push('\n' + _fs.readFileSync(_path.join(cwd, fileObj.path), 'utf8'));
	});

	return _convertReadme2ReadmeDTO(readmeFilesData.join(''));
}

module.exports = resolve(getReadmeFiles, {
	getConfig: getConfig,
	getConfigFilePath: getConfigFilePath,
	getCwd: getCwd,
	convertReadme2ReadmeDTO: convertReadme2ReadmeDTO,
	fs: fs,
	path: path,
	console: console
});
module.exports.getReadmeFiles = getReadmeFiles;